summaryrefslogtreecommitdiffstats
path: root/cc/texture_layer_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'cc/texture_layer_client.h')
-rw-r--r--cc/texture_layer_client.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cc/texture_layer_client.h b/cc/texture_layer_client.h
index 35e7fc5..9ebc8d5 100644
--- a/cc/texture_layer_client.h
+++ b/cc/texture_layer_client.h
@@ -10,14 +10,14 @@ class WebGraphicsContext3D;
}
namespace cc {
-class TextureUpdateQueue;
+class ResourceUpdateQueue;
class TextureLayerClient {
public:
// Called to prepare this layer's texture for compositing. The client may queue a texture
// upload or copy on the TextureUpdateQueue.
// Returns the texture ID to be used for compositing.
- virtual unsigned prepareTexture(TextureUpdateQueue&) = 0;
+ virtual unsigned prepareTexture(ResourceUpdateQueue&) = 0;
// Returns the context that is providing the texture. Used for rate limiting and detecting lost context.
virtual WebKit::WebGraphicsContext3D* context() = 0;
@@ -10,14 +10,14 @@ class WebGraphicsContext3D;
public:
// Called to prepare this layer's texture for compositing. The client may queue a texture
- // upload or copy on the TextureUpdateQueue.
+ // upload or copy on the ResourceUpdateQueue.
// Returns the texture ID to be used for compositing.